@@ -1,5 +1,5 @@
 package Mongoose;
-$Mongoose::VERSION = '0.29';
+$Mongoose::VERSION = '0.30';
 use MongoDB;
 use Class::MOP;
 use MooseX::Singleton;
@@ -7,15 +7,6 @@ use Mongoose::Join;
 use Mongoose::File;
 use Mongoose::Meta::AttributeTraits;
 use Moose::Util::TypeConstraints;
-
-# determine if we are on MongoDB 0.503.1
-require version;
-our $_mongodb_client_class =
-    version::qv( $MongoDB::VERSION ) >= v0.502.0
-        ? 'MongoDB::MongoClient'
-        : 'MongoDB::Connection';
-
-class_type $_mongodb_client_class;
 use Carp;
 
 has '_db' => (
@@ -132,7 +123,7 @@ sub connect {
     my $auth_db_name = delete $p{auth_db_name} || $data_db_name;
     $p{db_name} = $auth_db_name;    # in MongoDB::Client db_name is auth db, not necessarily data db
 
-    $self->_client->{$name} = $_mongodb_client_class->new(%p)
+    $self->_client->{$name} = MongoDB::MongoClient->new(%p)
       unless ref $self->_client->{$name};
 
     $self->_db->{$name} = $self->_client->{$name}->get_database( $data_db_name );
@@ -170,10 +161,6 @@ sub load_schema {
 
 Mongoose - MongoDB document to Moose object mapper
 
-=head1 VERSION
-
-version 0.29
-
 =head1 SYNOPSIS
 
     package Person;
@@ -412,3 +399,4 @@ L<KiokuDB>
 
 This library is free software. You can redistribute it and/or modify it under
 the same terms as Perl itself.
+
