@@ -1,5 +1,5 @@
 package Mongoose::Engine::Base;
-$Mongoose::Engine::Base::VERSION = '0.29';
+$Mongoose::Engine::Base::VERSION = '0.30';
 use Moose::Role;
 use Params::Coerce;
 use Scalar::Util qw/refaddr reftype/;
@@ -16,8 +16,7 @@ sub collapse {
     my ( $self, @scope )=@_;
 
     # circularity ?
-    if( my $duplicate = first { refaddr($self) == refaddr($_) } @scope ) { 
-        #say "----CIRC=$duplicate";
+    if( my $duplicate = first { refaddr($self) == refaddr($_) } @scope ) {
         my $class = blessed $duplicate;
         my $ref_id = $duplicate->_id;
         return undef unless defined $class && $ref_id;
@@ -30,8 +29,8 @@ sub collapse {
 
         # treat special cases based on Moose attribute defs or traits
         if( defined $attrib ) {
-            delete $packed->{$key} , next
-                if $attrib->does('Mongoose::Meta::Attribute::Trait::DoNotMongoSerialize');
+            delete $packed->{$key},
+                next if $attrib->does('Mongoose::Meta::Attribute::Trait::DoNotMongoSerialize');
 
             next if $attrib->does('Mongoose::Meta::Attribute::Trait::Raw');
 
@@ -50,27 +49,29 @@ sub collapse {
 
 sub _collapse {
     my ($self, $value, @scope ) = @_;
-    if( my $class = blessed $value ) {
-        #say "checking.... $class.... $self: " . $self->_id;
-        if( ref $value eq 'HASH' && defined ( my $ref_id = $value->{_id} ) ) {
+    if ( my $class = blessed $value ) {
+        if ( ref $value eq 'HASH' && defined ( my $ref_id = $value->{_id} ) ) {
             # it has an id, so join ref it
-            return Tie::IxHash->new( '$ref' => $class->meta->{mongoose_config}->{collection_name}, '$id'=>$ref_id );
-        } else {
+            return Tie::IxHash->new( '$ref' => $class->meta->{mongoose_config}{collection_name}, '$id'=>$ref_id );
+        }
+        else {
             return $self->_unbless( $value, $class, @scope );
         }
     }
-    elsif( ref $value eq 'ARRAY' ) {
+    elsif ( ref $value eq 'ARRAY' ) {
         my @docs;
         my $aryclass;
         for my $item ( @$value ) {
             $aryclass ||= blessed( $item );
-            if( $aryclass && $aryclass->does('Mongoose::EmbeddedDocument') ) {
+            if ( $aryclass && $aryclass->does('Mongoose::EmbeddedDocument') ) {
                 push @docs, $item->collapse(@scope, $self);
-            } elsif( $aryclass && $aryclass->does('Mongoose::Document') ) {
+            }
+            elsif ( $aryclass && $aryclass->does('Mongoose::Document') ) {
                 $item->_save( @scope, $self );
                 my $id = $item->_id;
-                push @docs, Tie::IxHash->new( '$ref' => $aryclass->meta->{mongoose_config}->{collection_name}, '$id'=>$id );
-            } else {
+                push @docs, Tie::IxHash->new( '$ref' => $aryclass->meta->{mongoose_config}{collection_name}, '$id'=>$id );
+            }
+            else {
                 push @docs, $item;
             }
         }
@@ -433,28 +434,27 @@ sub query {
 
 sub find_one {
     my $self = shift;
-    my $doc;
-    if( @_ == 1 && ! ref $_[0] ) {
-        $doc = $self->collection->find_one({ _id=>MongoDB::OID->new( value=>$_[0] ) });
-        return undef unless defined $doc;
-        return $self->expand( $doc );
+
+    if( @_ == 1 && ( !ref($_[0]) || ref($_[0]) eq 'MongoDB::OID' ) ) {
+        my $query = { _id=> ref $_[0] ? $_[0] : MongoDB::OID->new( value=>$_[0] ) };
+        if ( my $doc = $self->collection->find_one($query) ) {
+            return $self->expand( $doc );
+        }
     }
     else {
         my ($query,$fields, $scope) = @_;
-        $doc = $self->collection->find_one( $query, $fields );
-        return undef unless defined $doc;
-        return $self->expand( $doc, $fields, $scope );
+        if ( my $doc = $self->collection->find_one( $query, $fields ) ) {
+            return $self->expand( $doc, $fields, $scope );
+        }
     }
+
+    undef;
 }
 
 =head1 NAME
 
 Mongoose::Engine::Base - heavy lifting done here
 
-=head1 VERSION
-
-version 0.29
-
 =head1 DESCRIPTION
 
 The Mongoose standard engine. Does all the dirty work. Very monolithic.
@@ -468,15 +468,15 @@ Just like L<MongoDB::Collection/find_one>, but blesses the hash document
 into your class package.
 
 Also has a handy mode which allows
-retrieving an C<_id> directly from an string:
+retrieving an C<_id> directly from a MongoDB::OID or just a string:
 
-   my $author = Author->find_one( '4dd77f4ebf4342d711000000' ); 
+   my $author = Author->find_one( '4dd77f4ebf4342d711000000' );
 
 Which expands onto:
 
    my $author = Author->find_one({
        _id=>MongoDB::OID->new( value=>'4dd77f4ebf4342d711000000' )
-   }); 
+   });
 
 =head2 find
 
@@ -522,3 +522,4 @@ foreign object ids.
 =cut
 
 1;
+
