@@ -1,5 +1,5 @@
 package Mongoose::Join;
-$Mongoose::Join::VERSION = '0.29';
+$Mongoose::Join::VERSION = '0.30';
 use Moose;
 use Moose::Util::TypeConstraints;
 use Moose::Meta::TypeConstraint::Parameterizable;
@@ -15,9 +15,7 @@ $REGISTRY->add_type_constraint(
         constraint           => sub { die 'constrained' },
         constraint_generator => sub {
             my $type_parameter = shift;
-
-            #print "constraint_generator...@_\n";
-            return sub { return {} };
+            sub { return {} };
         }
     )
 );
@@ -216,10 +214,6 @@ sub _tie_refs {
 
 Mongoose::Join - simple class relationship resolver
 
-=head1 VERSION
-
-version 0.29
-
 =head1 SYNOPSIS
 
     package Author;
